==> mesa-21.1.1.tar.xz: mesa-21.1.1/src/gallium/auxiliary/util/u_threaded_context_calls.h <==
CALL(flush)
CALL(callback)
CALL(fence_server_sync)
CALL(fence_server_signal)
CALL(destroy_query)
CALL(begin_query)
CALL(end_query)
CALL(get_query_result_resource)
CALL(render_condition)
CALL(bind_sampler_states)
CALL(set_framebuffer_state)
CALL(set_tess_state)
CALL(set_constant_buffer)
CALL(set_inlinable_constants)
CALL(set_sample_locations)
CALL(set_scissor_states)
CALL(set_viewport_states)
CALL(set_window_rectangles)
CALL(set_sampler_views)
CALL(set_shader_images)
CALL(set_shader_buffers)
CALL(set_vertex_buffers)
CALL(set_stream_output_targets)
CALL(replace_buffer_storage)
CALL(transfer_flush_region)
CALL(transfer_unmap)
CALL(buffer_subdata)
CALL(texture_subdata)
CALL(emit_string_marker)
CALL(draw_single)
CALL(draw_multi)
CALL(draw_indirect)
CALL(launch_grid)
CALL(resource_copy_region)
CALL(blit)
CALL(generate_mipmap)
CALL(flush_resource)
CALL(invalidate_resource)
CALL(clear)
CALL(clear_buffer)
CALL(clear_texture)
CALL(resource_commit)
CALL(set_active_query_state)
CALL(set_blend_color)
CALL(set_stencil_ref)
CALL(set_clip_state)
CALL(set_sample_mask)
CALL(set_min_samples)
CALL(set_polygon_stipple)
CALL(texture_barrier)
CALL(memory_barrier)
CALL(delete_texture_handle)
CALL(make_texture_handle_resident)
CALL(delete_image_handle)
CALL(make_image_handle_resident)
CALL(set_context_param)
CALL(set_frontend_noop)

CALL(bind_blend_state)
CALL(bind_rasterizer_state)
CALL(bind_depth_stencil_alpha_state)
CALL(bind_compute_state)
CALL(bind_fs_state)
CALL(bind_vs_state)
CALL(bind_gs_state)
CALL(bind_tcs_state)
CALL(bind_tes_state)
CALL(bind_vertex_elements_state)

CALL(delete_blend_state)
CALL(delete_rasterizer_state)
CALL(delete_depth_stencil_alpha_state)
CALL(delete_compute_state)
CALL(delete_fs_state)
CALL(delete_vs_state)
CALL(delete_gs_state)
CALL(delete_tcs_state)
CALL(delete_tes_state)
CALL(delete_vertex_elements_state)
CALL(delete_sampler_state)

CALL(begin_intel_perf_query)
CALL(end_intel_perf_query)

==> mesa_21.3.8.3.orig.tar.xz: mesa-21.3.8.3/src/gallium/auxiliary/util/u_threaded_context_calls.h <==
CALL(flush)
CALL(callback)
CALL(fence_server_sync)
CALL(fence_server_signal)
CALL(destroy_query)
CALL(begin_query)
CALL(end_query)
CALL(get_query_result_resource)
CALL(render_condition)
CALL(bind_sampler_states)
CALL(set_framebuffer_state)
CALL(set_tess_state)
CALL(set_patch_vertices)
CALL(set_constant_buffer)
CALL(set_inlinable_constants)
CALL(set_sample_locations)
CALL(set_scissor_states)
CALL(set_viewport_states)
CALL(set_window_rectangles)
CALL(set_sampler_views)
CALL(set_shader_images)
CALL(set_shader_buffers)
CALL(set_vertex_buffers)
CALL(set_stream_output_targets)
CALL(replace_buffer_storage)
CALL(transfer_flush_region)
CALL(buffer_unmap)
CALL(texture_unmap)
CALL(buffer_subdata)
CALL(texture_subdata)
CALL(emit_string_marker)
CALL(draw_single)
CALL(draw_single_drawid)
CALL(draw_multi)
CALL(draw_indirect)
CALL(draw_vstate_single)
CALL(draw_vstate_multi)
CALL(launch_grid)
CALL(resource_copy_region)
CALL(blit)
CALL(generate_mipmap)
CALL(flush_resource)
CALL(invalidate_resource)
CALL(clear)
CALL(clear_render_target)
CALL(clear_depth_stencil)
CALL(clear_buffer)
CALL(clear_texture)
CALL(resource_commit)
CALL(set_active_query_state)
CALL(set_blend_color)
CALL(set_stencil_ref)
CALL(set_clip_state)
CALL(set_sample_mask)
CALL(set_min_samples)
CALL(set_polygon_stipple)
CALL(texture_barrier)
CALL(memory_barrier)
CALL(delete_texture_handle)
CALL(make_texture_handle_resident)
CALL(delete_image_handle)
CALL(make_image_handle_resident)
CALL(set_context_param)
CALL(set_frontend_noop)

CALL(bind_blend_state)
CALL(bind_rasterizer_state)
CALL(bind_depth_stencil_alpha_state)
CALL(bind_compute_state)
CALL(bind_fs_state)
CALL(bind_vs_state)
CALL(bind_gs_state)
CALL(bind_tcs_state)
CALL(bind_tes_state)
CALL(bind_vertex_elements_state)

CALL(delete_blend_state)
CALL(delete_rasterizer_state)
CALL(delete_depth_stencil_alpha_state)
CALL(delete_compute_state)
CALL(delete_fs_state)
CALL(delete_vs_state)
CALL(delete_gs_state)
CALL(delete_tcs_state)
CALL(delete_tes_state)
CALL(delete_vertex_elements_state)
CALL(delete_sampler_state)

CALL(begin_intel_perf_query)
CALL(end_intel_perf_query)
